@@ -14,7 +14,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-//$Id: radioactive.h,v 1.23 2001/02/07 17:05:07 cactus Exp $ -*- c++ -*-
+//$Id: radioactive.h,v 1.24 2001/11/06 17:45:38 cactus Exp $ -*- c++ -*-
 #ifndef RADIO_h
 #define RADIO_h
 
@@ -36,5 +36,10 @@
 // Stupid error in the stock libgnome/libgnome.h
 #include <libgnome/libgnome.h>
 
+#include <string>
+#include <vector>
+
+typedef std::pair<float, std::string> StationData;
+typedef std::vector<StationData>      SpeedButtonData;
 
 #endif
